==> aTunes_1.13.2.tar.gz: aTunes/src/net/sourceforge/atunes/kernel/actions/ExtractPictureAction.java <==
/*
 * aTunes 1.13.2
 * Copyright (C) 2006-2009 Alex Aranda, Sylvain Gaudard, Thomas Beckers and contributors
 *
 * See http://www.atunes.org/wiki/index.php?title=Contributing for information about contributors
 *
 * http://www.atunes.org
 * http://sourceforge.net/projects/atunes
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */

package net.sourceforge.atunes.kernel.actions;

import java.awt.event.ActionEvent;

import javax.swing.AbstractAction;

import net.sourceforge.atunes.gui.images.ImageLoader;
import net.sourceforge.atunes.gui.model.NavigationTableModel;
import net.sourceforge.atunes.kernel.ControllerProxy;
import net.sourceforge.atunes.kernel.modules.repository.audio.AudioFile;
import net.sourceforge.atunes.model.AudioObject;
import net.sourceforge.atunes.utils.AudioFilePictureUtils;
import net.sourceforge.atunes.utils.LanguageTool;

public class ExtractPictureAction extends AbstractAction {

    private static final long serialVersionUID = -8618297820141610193L;

    ExtractPictureAction() {
        super(LanguageTool.getString("EXTRACT_PICTURE"), ImageLoader.EXPORT_PICTURE);
        putValue(SHORT_DESCRIPTION, LanguageTool.getString("EXTRACT_PICTURE"));
    }

    @Override
    public void actionPerformed(ActionEvent e) {
        AudioObject file = ((NavigationTableModel) ControllerProxy.getInstance().getNavigationController().getNavigationPanel().getNavigationTable().getModel())
                .getSongAt(ControllerProxy.getInstance().getNavigationController().getNavigationPanel().getNavigationTable().getSelectedRow());
        try {
            AudioFilePictureUtils.exportPicture((AudioFile) file);
        } catch (Exception ex) {
            Actions.error(ex.getMessage());
        }
    }

}

==> aTunes_1.13.6.tar.gz: aTunes/src/net/sourceforge/atunes/kernel/actions/ExtractPictureAction.java <==
/*
 * aTunes 1.13.6
 * Copyright (C) 2006-2009 Alex Aranda, Sylvain Gaudard, Thomas Beckers and contributors
 *
 * See http://www.atunes.org/wiki/index.php?title=Contributing for information about contributors
 *
 * http://www.atunes.org
 * http://sourceforge.net/projects/atunes
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */

package net.sourceforge.atunes.kernel.actions;

import java.awt.event.ActionEvent;

import javax.swing.AbstractAction;

import net.sourceforge.atunes.gui.images.ImageLoader;
import net.sourceforge.atunes.gui.model.NavigationTableModel;
import net.sourceforge.atunes.kernel.ControllerProxy;
import net.sourceforge.atunes.kernel.modules.repository.audio.AudioFile;
import net.sourceforge.atunes.kernel.modules.visual.VisualHandler;
import net.sourceforge.atunes.model.AudioObject;
import net.sourceforge.atunes.utils.AudioFilePictureUtils;
import net.sourceforge.atunes.utils.LanguageTool;

public class ExtractPictureAction extends AbstractAction {

    private static final long serialVersionUID = -8618297820141610193L;

    ExtractPictureAction() {
        super(LanguageTool.getString("EXTRACT_PICTURE"), ImageLoader.EXPORT_PICTURE);
        putValue(SHORT_DESCRIPTION, LanguageTool.getString("EXTRACT_PICTURE"));
    }

    @Override
    public void actionPerformed(ActionEvent e) {
        AudioObject file = ((NavigationTableModel) ControllerProxy.getInstance().getNavigationController().getNavigationPanel().getNavigationTable().getModel())
                .getSongAt(ControllerProxy.getInstance().getNavigationController().getNavigationPanel().getNavigationTable().getSelectedRow());
        try {
            AudioFilePictureUtils.exportPicture((AudioFile) file, VisualHandler.getInstance().getFrame().getFrame());
        } catch (Exception ex) {
            Actions.error(ex.getMessage());
        }
    }

}
